Package: MSA2dist
Type: Package
Title: MSA2dist calculates pairwise distances between all sequences of
        a DNAStringSet or a AAStringSet using a custom score matrix and
        conducts codon based analysis
Version: 1.15.0
Authors@R: 
    person(given = "Kristian K",
           family = "Ullrich",
           role = c("aut", "cre"),
           email = "ullrich@evolbio.mpg.de",
           comment = c(ORCID = "0000-0003-4308-9626"))
Description: MSA2dist calculates pairwise distances between all sequences of
    a DNAStringSet or a AAStringSet using a custom score matrix and conducts
    codon based analysis. It uses scoring matrices to be used in these pairwise
    distance calculations which can be adapted to any scoring for DNA or AA
    characters. E.g. by using literal distances MSA2dist calculates pairwise
    IUPAC distances. DNAStringSet alignments can be analysed as codon alignments
    to look for synonymous and nonsynonymous substitutions (dN/dS) in a
    parallelised fashion using a variety of substitution models. Non-aligned
    coding sequences can be directly used to construct pairwise codon
    alignments (global/local) and calculate dN/dS without any external
    dependencies.
License: GPL-3 + file LICENSE
Encoding: UTF-8
LazyData: false
biocViews: Alignment, Sequencing, Genetics, GO
Depends: R (>= 4.4.0)
Imports: Rcpp, Biostrings, GenomicRanges, IRanges, ape, doParallel,
        dplyr, foreach, methods, parallel, pwalign, rlang, seqinr,
        stats, stringi, stringr, tibble, tidyr, utils
Suggests: rmarkdown, knitr, devtools, testthat, ggplot2, BiocStyle
LinkingTo: Rcpp, RcppThread
VignetteBuilder: knitr
NeedsCompilation: yes
SystemRequirements: C++11
URL: https://gitlab.gwdg.de/mpievolbio-it/MSA2dist,
        https://mpievolbio-it.pages.gwdg.de/MSA2dist/
BugReports: https://gitlab.gwdg.de/mpievolbio-it/MSA2dist/issues
RoxygenNote: 7.3.1
git_url: https://git.bioconductor.org/packages/MSA2dist
git_branch: devel
git_last_commit: 662eead
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
Packaged: 2025-10-31 23:01:04 UTC; biocbuild
Author: Kristian K Ullrich [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4308-9626>)
Maintainer: Kristian K Ullrich <ullrich@evolbio.mpg.de>
