# Generated by roxygen2: do not edit by hand

export(GENETIC_CODE_TCAG)
export(aa2selfscore)
export(aabin2aastring)
export(aastring2aabin)
export(aastring2aln)
export(aastring2dist)
export(addmask2string)
export(addpop2string)
export(addpos2string)
export(addregion2string)
export(aln2aastring)
export(aln2dnastring)
export(cds2aa)
export(cds2codonaln)
export(cdsstring2codonaln)
export(codon2numberAMBIG)
export(codon2numberTCAG)
export(codonmat2pnps)
export(codonmat2xy)
export(compareCodons)
export(dnabin2dnastring)
export(dnastring2aln)
export(dnastring2codonmat)
export(dnastring2dist)
export(dnastring2dnabin)
export(dnastring2kaks)
export(getmask)
export(getpos)
export(globalDeletion)
export(globalDeletionAA)
export(granthamMatrix)
export(indices2kaks)
export(iupacMatrix)
export(makePostalignedSeqs)
export(pal2nal)
export(popinteger)
export(popnames)
export(rcpp_KaKs)
export(rcpp_distSTRING)
export(rcpp_pairwiseDeletionAA)
export(rcpp_pairwiseDeletionDNA)
export(region)
export(regionused)
export(string2region)
export(subString)
export(uptriidx)
import(Rcpp)
importFrom(Biostrings,AAMultipleAlignment)
importFrom(Biostrings,AAString)
importFrom(Biostrings,AAStringSet)
importFrom(Biostrings,BString)
importFrom(Biostrings,BStringSet)
importFrom(Biostrings,DNAString)
importFrom(Biostrings,DNAStringSet)
importFrom(Biostrings,GENETIC_CODE)
importFrom(Biostrings,GENETIC_CODE_TABLE)
importFrom(Biostrings,RNAString)
importFrom(Biostrings,RNAStringSet)
importFrom(Biostrings,consensusMatrix)
importFrom(Biostrings,getGeneticCode)
importFrom(Biostrings,readAAStringSet)
importFrom(Biostrings,readDNAStringSet)
importFrom(Biostrings,subseq)
importFrom(Biostrings,translate)
importFrom(Biostrings,width)
importFrom(Biostrings,writeXStringSet)
importFrom(GenomicRanges,GRanges)
importFrom(IRanges,IRanges)
importFrom(IRanges,IRangesList)
importFrom(IRanges,disjoin)
importFrom(IRanges,end)
importFrom(IRanges,findOverlaps)
importFrom(IRanges,overlapsRanges)
importFrom(IRanges,reduce)
importFrom(IRanges,start)
importFrom(ape,as.AAbin)
importFrom(ape,as.DNAbin.alignment)
importFrom(ape,dist.dna)
importFrom(doParallel,registerDoParallel)
importFrom(dplyr,count)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(foreach,"%do%")
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(methods,is)
importFrom(methods,slot)
importFrom(parallel,makeForkCluster)
importFrom(parallel,stopCluster)
importFrom(pwalign,pairwiseAlignment)
importFrom(rlang,.data)
importFrom(seqinr,as.alignment)
importFrom(seqinr,kaks)
importFrom(stats,setNames)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,word)
importFrom(tibble,add_column)
importFrom(tibble,column_to_rownames)
importFrom(tidyr,"%>%")
importFrom(tidyr,as_tibble)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,unite)
importFrom(utils,data)
useDynLib(MSA2dist, .registration = TRUE)
