#' @title AAMatrix-data
#' @name AAMatrix-data
#' @description \code{getAAMatrix()}  from the \code{alakazam} package.
#' @return \code{score matrix}
#' @references Gupta N, Vander Heiden J, Uduman M, Gadala-Maria D, Yaari G,
#' Kleinstein S (2015) Change-O: a toolkit for analyzing large-scale B cell
#' immunoglobulin repertoire sequencing data. \emph{Bioinformatics.}
#' \bold{31(20)}, 3356-3358.
#' @docType data
#' @usage data(AAMatrix)
#' @format an object of class \code{matrix}
#' @keywords datasets
#' @examples
#' data("AAMatrix", package="MSA2dist")

"AAMatrix"
