data(hiv)

test_that("subString()", {
    expect_true(as.character(subString(hiv,c(1,2),c(3,4))[1]) == "GTATAG")
    expect_true(as.character(subString(Biostrings::DNAStringSet("ATG"),1,2))
    == "AT")
    expect_true(as.character(subString(Biostrings::DNAString("ATG"),1,2))
    == "AT")
        expect_true(as.character(subString(Biostrings::BStringSet("ATG"),1,2))
    == "AT")
    expect_true(as.character(subString(Biostrings::BString("ATG"),1,2))
    == "AT")
        expect_true(as.character(subString(Biostrings::RNAStringSet("AUG"),1,2))
    == "AU")
    expect_true(as.character(subString(Biostrings::RNAString("AUG"),1,2))
    == "AU")
        expect_true(as.character(subString(Biostrings::AAStringSet("MGP"),1,2))
    == "MG")
    expect_true(as.character(subString(Biostrings::AAString("MGP"),1,2))
    == "MG")
})
